package javax.swing;

import java.util.Enumeration;
import java.util.Vector;

public class DefaultListModel<E> extends AbstractListModel<E>
{
    private Vector<E> delegate;
    
    public DefaultListModel() {
        this.delegate = new Vector();
    }
    
    @Override
    public int getSize() {
        return this.delegate.size();
    }
    
    @Override
    public E getElementAt(int index) {
        return this.delegate.elementAt(index);
    }
    
    public void copyInto(Object[] anArray) {
        this.delegate.copyInto(anArray);
    }
    
    public void trimToSize() {
        this.delegate.trimToSize();
    }
    
    public void ensureCapacity(int minCapacity) {
        this.delegate.ensureCapacity(minCapacity);
    }
    
    public void setSize(int size) {
        int size2 = this.delegate.size();
        this.delegate.setSize(size);
        if (size2 > size) {
            this.fireIntervalRemoved(this, size, size2 - 1);
        }
        else if (size2 < size) {
            this.fireIntervalAdded(this, size2, size - 1);
        }
    }
    
    public int capacity() {
        return this.delegate.capacity();
    }
    
    public int size() {
        return this.delegate.size();
    }
    
    public boolean isEmpty() {
        return this.delegate.isEmpty();
    }
    
    public Enumeration<E> elements() {
        return this.delegate.elements();
    }
    
    public boolean contains(Object o) {
        return this.delegate.contains(o);
    }
    
    public int indexOf(Object o) {
        return this.delegate.indexOf(o);
    }
    
    public int indexOf(Object o, int index) {
        return this.delegate.indexOf(o, index);
    }
    
    public int lastIndexOf(Object o) {
        return this.delegate.lastIndexOf(o);
    }
    
    public int lastIndexOf(Object o, int index) {
        return this.delegate.lastIndexOf(o, index);
    }
    
    public E elementAt(int index) {
        return this.delegate.elementAt(index);
    }
    
    public E firstElement() {
        return this.delegate.firstElement();
    }
    
    public E lastElement() {
        return this.delegate.lastElement();
    }
    
    public void setElementAt(E obj, int index) {
        this.delegate.setElementAt(obj, index);
        this.fireContentsChanged(this, index, index);
    }
    
    public void removeElementAt(int index) {
        this.delegate.removeElementAt(index);
        this.fireIntervalRemoved(this, index, index);
    }
    
    public void insertElementAt(E obj, int index) {
        this.delegate.insertElementAt(obj, index);
        this.fireIntervalAdded(this, index, index);
    }
    
    public void addElement(E obj) {
        int size = this.delegate.size();
        this.delegate.addElement(obj);
        this.fireIntervalAdded(this, size, size);
    }
    
    public boolean removeElement(Object obj) {
        int index = this.indexOf(obj);
        int removeElement = this.delegate.removeElement(obj);
        if (index >= 0) {
            this.fireIntervalRemoved(this, index, index);
        }
        return removeElement;
    }
    
    public void removeAllElements() {
        int n = this.delegate.size() - 1;
        this.delegate.removeAllElements();
        if (n >= 0) {
            this.fireIntervalRemoved(this, 0, n);
        }
    }
    
    @Override
    public String toString() {
        return this.delegate.toString();
    }
    
    public Object[] toArray() {
        Object[] anArray = new Object[this.delegate.size()];
        this.delegate.copyInto(anArray);
        return anArray;
    }
    
    public E get(int index) {
        return this.delegate.elementAt(index);
    }
    
    public E set(int n, E obj) {
        Object element = this.delegate.elementAt(n);
        this.delegate.setElementAt(obj, n);
        this.fireContentsChanged(this, n, n);
        return element;
    }
    
    public void add(int index, E obj) {
        this.delegate.insertElementAt(obj, index);
        this.fireIntervalAdded(this, index, index);
    }
    
    public E remove(int n) {
        Object element = this.delegate.elementAt(n);
        this.delegate.removeElementAt(n);
        this.fireIntervalRemoved(this, n, n);
        return element;
    }
    
    public void clear() {
        int n = this.delegate.size() - 1;
        this.delegate.removeAllElements();
        if (n >= 0) {
            this.fireIntervalRemoved(this, 0, n);
        }
    }
    
    public void removeRange(int n, int i) {
        if (n > i) {
            throw new IllegalArgumentException("fromIndex must be <= toIndex");
        }
        for (; i >= n; --i) {
            this.delegate.removeElementAt(i);
        }
        this.fireIntervalRemoved(this, n, i);
        return;
    }
}
